from src.deFIBrillator import FIBG2, plot_stream_file, print_streamfile_time
from time import perf_counter

# Set up FIB
fib = FIBG2()
fib.set_fov(70, "um")
fib.set_beam(fib.Beams.Acceleration30kV.pA93)
print(fib)

# Create pattern
pat = fib.new_pattern()
pat.set_dwell_time(0.9, "us")
pat.set_material(pat.Materials.Au)
pat.set_depth(177, "nm")
pat.set_scan_style(pat.ScanStyles.contour_outward)

# Create bounds
bounds = pat.add.rectangle(x_span=40000, y_span=4000)

# Create honeycomb lattice
lattice = pat.add.lattice(rows=50800//800, cols=50800//800, alpha=350*2 + 100, beta=350*2 + 100, gamma=60,
                          shape=pat.add.regular_polygon(inner_radius=350, millable=False))
bounds.x_span = lattice.x_max * 2 - 800
bounds.y_span = lattice.y_max * 2 - 800

start = perf_counter()
pat.write_stream("test")
print("Stream file creation took " + str((perf_counter() - start) / 60) + " minutes.")
print_streamfile_time("test")
